pub struct Finding {
pub id: String,
pub kind: String,
pub severity: String,
pub project_key: String,
pub file_path: String,
pub lines: [u32; 2],
pub related: Vec<FileRef>,
}Expand description
One finding: what kind, how bad, where. Nothing else, ever: see the
module docs and check_finding.
Fields
id: Stringf1, f2, …: unique within its report, and how details and
recall eval apply name it.
kind: StringOne of KINDS.
severity: StringOne of SEVERITIES.
project_key: StringThe project the file belongs to.
file_path: StringThe file.
lines: [u32; 2]The first and last line it concerns, counting from 1.
Other files it concerns: where a duplicate’s first copy is, or what a note contradicts.